# coding: utf-8

"""
    Platform API

    _OpenAPI specification for the **Platform API** of **Empire**, the allocation and nomination platform of BritNed_  ---  Additional documentation available in the API's [GitHub repository](https://github.com/britned/empire-platform-api) 

    The version of the OpenAPI document: 6.0.4
    Contact: britned.info@britned.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from empire_platform_api_public_client.api.secondary_market_api import SecondaryMarketApi


class TestSecondaryMarketApi(unittest.TestCase):
    """SecondaryMarketApi unit test stubs"""

    def setUp(self) -> None:
        self.api = SecondaryMarketApi()

    def tearDown(self) -> None:
        pass

    def test_accept_secondary_market_transfer_request(self) -> None:
        """Test case for accept_secondary_market_transfer_request

        """
        pass

    def test_create_day_ahead_or_intra_day_secondary_market_noticeboard_entry(self) -> None:
        """Test case for create_day_ahead_or_intra_day_secondary_market_noticeboard_entry

        """
        pass

    def test_create_day_ahead_or_intra_day_secondary_market_transfer_request(self) -> None:
        """Test case for create_day_ahead_or_intra_day_secondary_market_transfer_request

        """
        pass

    def test_create_day_ahead_or_intraday_secondary_noticeboard_response(self) -> None:
        """Test case for create_day_ahead_or_intraday_secondary_noticeboard_response

        """
        pass

    def test_create_long_term_secondary_market_noticeboard_entry(self) -> None:
        """Test case for create_long_term_secondary_market_noticeboard_entry

        """
        pass

    def test_create_long_term_secondary_market_transfer_request(self) -> None:
        """Test case for create_long_term_secondary_market_transfer_request

        """
        pass

    def test_create_long_term_secondary_noticeboard_response(self) -> None:
        """Test case for create_long_term_secondary_noticeboard_response

        """
        pass

    def test_create_secondary_market_return_request(self) -> None:
        """Test case for create_secondary_market_return_request

        """
        pass

    def test_delete_noticeboard_entry(self) -> None:
        """Test case for delete_noticeboard_entry

        """
        pass

    def test_get_day_ahead_or_intra_day_secondary_market_noticeboard_entry(self) -> None:
        """Test case for get_day_ahead_or_intra_day_secondary_market_noticeboard_entry

        """
        pass

    def test_get_day_ahead_or_intra_day_secondary_market_transfer_request(self) -> None:
        """Test case for get_day_ahead_or_intra_day_secondary_market_transfer_request

        """
        pass

    def test_get_day_ahead_or_intra_day_secondary_market_transfer_request_options(self) -> None:
        """Test case for get_day_ahead_or_intra_day_secondary_market_transfer_request_options

        """
        pass

    def test_get_day_ahead_or_intraday_secondary_market_noticeboard_options(self) -> None:
        """Test case for get_day_ahead_or_intraday_secondary_market_noticeboard_options

        """
        pass

    def test_get_day_ahead_or_intraday_secondary_market_noticeboard_response_options(self) -> None:
        """Test case for get_day_ahead_or_intraday_secondary_market_noticeboard_response_options

        """
        pass

    def test_get_long_term_secondary_market_noticeboard_entry(self) -> None:
        """Test case for get_long_term_secondary_market_noticeboard_entry

        """
        pass

    def test_get_long_term_secondary_market_noticeboard_options(self) -> None:
        """Test case for get_long_term_secondary_market_noticeboard_options

        """
        pass

    def test_get_long_term_secondary_market_noticeboard_response_options(self) -> None:
        """Test case for get_long_term_secondary_market_noticeboard_response_options

        """
        pass

    def test_get_long_term_secondary_market_transfer_request(self) -> None:
        """Test case for get_long_term_secondary_market_transfer_request

        """
        pass

    def test_get_long_term_secondary_market_transfer_request_options(self) -> None:
        """Test case for get_long_term_secondary_market_transfer_request_options

        """
        pass

    def test_get_secondary_market_noticeboard(self) -> None:
        """Test case for get_secondary_market_noticeboard

        """
        pass

    def test_get_secondary_market_return_request_options(self) -> None:
        """Test case for get_secondary_market_return_request_options

        """
        pass

    def test_get_secondary_market_return_requests(self) -> None:
        """Test case for get_secondary_market_return_requests

        """
        pass

    def test_get_secondary_market_transfer_requests(self) -> None:
        """Test case for get_secondary_market_transfer_requests

        """
        pass

    def test_reject_secondary_market_transfer_request(self) -> None:
        """Test case for reject_secondary_market_transfer_request

        """
        pass

    def test_withdraw_secondary_market_return_request(self) -> None:
        """Test case for withdraw_secondary_market_return_request

        """
        pass

    def test_withdraw_secondary_market_transfer_request(self) -> None:
        """Test case for withdraw_secondary_market_transfer_request

        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Platform API

    _OpenAPI specification for the **Platform API** of **Empire**, the allocation and nomination platform of BritNed_  ---  Additional documentation available in the API's [GitHub repository](https://github.com/britned/empire-platform-api) 

    The version of the OpenAPI document: 6.0.4
    Contact: britned.info@britned.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from empire_platform_api_public_client.models.secondary_market_transfer_request_batch import SecondaryMarketTransferRequestBatch

class TestSecondaryMarketTransferRequestBatch(unittest.TestCase):
    """SecondaryMarketTransferRequestBatch unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> SecondaryMarketTransferRequestBatch:
        """Test SecondaryMarketTransferRequestBatch
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `SecondaryMarketTransferRequestBatch`
        """
        model = SecondaryMarketTransferRequestBatch()
        if include_optional:
            return SecondaryMarketTransferRequestBatch(
                entries = [
                    empire_platform_api_public_client.models.secondary_market_transfer_request.SecondaryMarketTransferRequest(
                        id = '8d3787bb-b9ce-4d75-9a75-074ddd5d1e09', 
                        timescale = 'LONG_TERM', 
                        delivery_period = empire_platform_api_public_client.models.date_period.DatePeriod(
                            start = '2022-01-04', 
                            end = '2022-01-04', ), 
                        direction = 'GB_NL', 
                        transferred_capacity = 56, 
                        requested_at = '2022-01-04T00:00:00.000Z', 
                        updated_at = '2022-01-04T00:00:00.000Z', 
                        completed_at = '2022-01-04T00:00:00.000Z', 
                        expires_at = '2022-01-04T00:00:00.000Z', 
                        sender = empire_platform_api_public_client.models.invoice_participant_details.InvoiceParticipantDetails(
                            id = '8d3787bb-b9ce-4d75-9a75-074ddd5d1e09', 
                            name = '', ), 
                        receiver = empire_platform_api_public_client.models.invoice_participant_details.InvoiceParticipantDetails(
                            id = '8d3787bb-b9ce-4d75-9a75-074ddd5d1e09', 
                            name = '', ), 
                        status = 'PENDING', )
                    ],
                total_count = 0
            )
        else:
            return SecondaryMarketTransferRequestBatch(
                entries = [
                    empire_platform_api_public_client.models.secondary_market_transfer_request.SecondaryMarketTransferRequest(
                        id = '8d3787bb-b9ce-4d75-9a75-074ddd5d1e09', 
                        timescale = 'LONG_TERM', 
                        delivery_period = empire_platform_api_public_client.models.date_period.DatePeriod(
                            start = '2022-01-04', 
                            end = '2022-01-04', ), 
                        direction = 'GB_NL', 
                        transferred_capacity = 56, 
                        requested_at = '2022-01-04T00:00:00.000Z', 
                        updated_at = '2022-01-04T00:00:00.000Z', 
                        completed_at = '2022-01-04T00:00:00.000Z', 
                        expires_at = '2022-01-04T00:00:00.000Z', 
                        sender = empire_platform_api_public_client.models.invoice_participant_details.InvoiceParticipantDetails(
                            id = '8d3787bb-b9ce-4d75-9a75-074ddd5d1e09', 
                            name = '', ), 
                        receiver = empire_platform_api_public_client.models.invoice_participant_details.InvoiceParticipantDetails(
                            id = '8d3787bb-b9ce-4d75-9a75-074ddd5d1e09', 
                            name = '', ), 
                        status = 'PENDING', )
                    ],
                total_count = 0,
        )
        """

    def testSecondaryMarketTransferRequestBatch(self):
        """Test SecondaryMarketTransferRequestBatch"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Platform API

    _OpenAPI specification for the **Platform API** of **Empire**, the allocation and nomination platform of BritNed_  ---  Additional documentation available in the API's [GitHub repository](https://github.com/britned/empire-platform-api) 

    The version of the OpenAPI document: 6.0.4
    Contact: britned.info@britned.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501

import warnings
from pydantic import validate_call, Field, StrictFloat, StrictStr, StrictInt
from typing import Any, Dict, List, Optional, Tuple, Union
from typing_extensions import Annotated

from datetime import date
from pydantic import Field, StrictBytes, StrictStr
from typing import List, Optional, Union
from typing_extensions import Annotated
from empire_platform_api_public_client.models.auction_product_type import AuctionProductType
from empire_platform_api_public_client.models.auction_timescale import AuctionTimescale
from empire_platform_api_public_client.models.border_direction import BorderDirection
from empire_platform_api_public_client.models.invoice_details import InvoiceDetails
from empire_platform_api_public_client.models.invoice_group_batch import InvoiceGroupBatch
from empire_platform_api_public_client.models.invoice_status import InvoiceStatus
from empire_platform_api_public_client.models.settlement import Settlement
from empire_platform_api_public_client.models.settlement_per_source import SettlementPerSource
from empire_platform_api_public_client.models.settlement_source_type import SettlementSourceType
from empire_platform_api_public_client.models.uiosi_overview import UiosiOverview

from empire_platform_api_public_client.api_client import ApiClient, RequestSerialized
from empire_platform_api_public_client.api_response import ApiResponse
from empire_platform_api_public_client.rest import RESTResponseType


class FinanceApi:
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None) -> None:
        if api_client is None:
            api_client = ApiClient.get_default()
        self.api_client = api_client


    @validate_call
    def download_all_finance_invoice_group_pdfs(
        self,
        id: Annotated[StrictStr, Field(description="Internal unique ID of an entity")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> bytearray:
        """download_all_finance_invoice_group_pdfs

        Fetch Invoice PDFs for an Invoice Group packaged in a ZIP archive  ---  __Requires Permission:__ (at least one)   * `VIEW_OWN_INVOICES`   * `VIEW_ANY_INVOICES`

        :param id: Internal unique ID of an entity (required)
        :type id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._download_all_finance_invoice_group_pdfs_serialize(
            id=id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "bytearray",
            '401': "ErrorResponse",
            '403': "ErrorResponse",
            '404': "ErrorResponse",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def download_all_finance_invoice_group_pdfs_with_http_info(
        self,
        id: Annotated[StrictStr, Field(description="Internal unique ID of an entity")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[bytearray]:
        """download_all_finance_invoice_group_pdfs

        Fetch Invoice PDFs for an Invoice Group packaged in a ZIP archive  ---  __Requires Permission:__ (at least one)   * `VIEW_OWN_INVOICES`   * `VIEW_ANY_INVOICES`

        :param id: Internal unique ID of an entity (required)
        :type id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._download_all_finance_invoice_group_pdfs_serialize(
            id=id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "bytearray",
            '401': "ErrorResponse",
            '403': "ErrorResponse",
            '404': "ErrorResponse",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def download_all_finance_invoice_group_pdfs_without_preload_content(
        self,
        id: Annotated[StrictStr, Field(description="Internal unique ID of an entity")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """download_all_finance_invoice_group_pdfs

        Fetch Invoice PDFs for an Invoice Group packaged in a ZIP archive  ---  __Requires Permission:__ (at least one)   * `VIEW_OWN_INVOICES`   * `VIEW_ANY_INVOICES`

        :param id: Internal unique ID of an entity (required)
        :type id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._download_all_finance_invoice_group_pdfs_serialize(
            id=id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "bytearray",
            '401': "ErrorResponse",
            '403': "ErrorResponse",
            '404': "ErrorResponse",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _download_all_finance_invoice_group_pdfs_serialize(
        self,
        id,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if id is not None:
            _path_params['id'] = id
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/octet-stream', 
                    'application/json'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
            'ApiKey'
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/v1/finance/invoice-groups/{id}/download-all',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def get_finance_invoice(
        self,
        id: Annotated[StrictStr, Field(description="Internal unique ID of an entity")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> InvoiceDetails:
        """get_finance_invoice

        Fetch an Invoice by its identifier  ---  __Requires Permission:__ (at least one)   * `VIEW_OWN_INVOICES`   * `VIEW_ANY_INVOICES`

        :param id: Internal unique ID of an entity (required)
        :type id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_finance_invoice_serialize(
            id=id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "InvoiceDetails",
            '401': "ErrorResponse",
            '403': "ErrorResponse",
            '404': "ErrorResponse",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def get_finance_invoice_with_http_info(
        self,
        id: Annotated[StrictStr, Field(description="Internal unique ID of an entity")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[InvoiceDetails]:
        """get_finance_invoice

        Fetch an Invoice by its identifier  ---  __Requires Permission:__ (at least one)   * `VIEW_OWN_INVOICES`   * `VIEW_ANY_INVOICES`

        :param id: Internal unique ID of an entity (required)
        :type id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_finance_invoice_serialize(
            id=id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "InvoiceDetails",
            '401': "ErrorResponse",
            '403': "ErrorResponse",
            '404': "ErrorResponse",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def get_finance_invoice_without_preload_content(
        self,
        id: Annotated[StrictStr, Field(description="Internal unique ID of an entity")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """get_finance_invoice

        Fetch an Invoice by its identifier  ---  __Requires Permission:__ (at least one)   * `VIEW_OWN_INVOICES`   * `VIEW_ANY_INVOICES`

        :param id: Internal unique ID of an entity (required)
        :type id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_finance_invoice_serialize(
            id=id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "InvoiceDetails",
            '401': "ErrorResponse",
            '403': "ErrorResponse",
            '404': "ErrorResponse",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _get_finance_invoice_serialize(
        self,
        id,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if id is not None:
            _path_params['id'] = id
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
            'ApiKey'
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/v1/finance/invoices/{id}',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def get_finance_invoices(
        self,
        limit: Annotated[int, Field(le=100, strict=True, ge=1, description="Number of records to return on a page")],
        offset: Annotated[int, Field(strict=True, ge=0, description="Offset in the list of records to return")],
        period_from: date,
        period_to: date,
        statuses: List[InvoiceStatus],
        x_participant_id: Annotated[Optional[StrictStr], Field(description="Internal ID of a Participant-type Organisation (optional)")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> InvoiceGroupBatch:
        """get_finance_invoices

        Fetch a paginated, filterable list of Invoices  ---  __Requires Permission:__ (at least one)   * `VIEW_OWN_INVOICES`   * `VIEW_ANY_INVOICES`

        :param limit: Number of records to return on a page (required)
        :type limit: int
        :param offset: Offset in the list of records to return (required)
        :type offset: int
        :param period_from: (required)
        :type period_from: date
        :param period_to: (required)
        :type period_to: date
        :param statuses: (required)
        :type statuses: List[InvoiceStatus]
        :param x_participant_id: Internal ID of a Participant-type Organisation (optional)
        :type x_participant_id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_finance_invoices_serialize(
            limit=limit,
            offset=offset,
            period_from=period_from,
            period_to=period_to,
            statuses=statuses,
            x_participant_id=x_participant_id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "InvoiceGroupBatch",
            '400': "ErrorResponse",
            '401': "ErrorResponse",
            '403': "ErrorResponse",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def get_finance_invoices_with_http_info(
        self,
        limit: Annotated[int, Field(le=100, strict=True, ge=1, description="Number of records to return on a page")],
        offset: Annotated[int, Field(strict=True, ge=0, description="Offset in the list of records to return")],
        period_from: date,
        period_to: date,
        statuses: List[InvoiceStatus],
        x_participant_id: Annotated[Optional[StrictStr], Field(description="Internal ID of a Participant-type Organisation (optional)")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[InvoiceGroupBatch]:
        """get_finance_invoices

        Fetch a paginated, filterable list of Invoices  ---  __Requires Permission:__ (at least one)   * `VIEW_OWN_INVOICES`   * `VIEW_ANY_INVOICES`

        :param limit: Number of records to return on a page (required)
        :type limit: int
        :param offset: Offset in the list of records to return (required)
        :type offset: int
        :param period_from: (required)
        :type period_from: date
        :param period_to: (required)
        :type period_to: date
        :param statuses: (required)
        :type statuses: List[InvoiceStatus]
        :param x_participant_id: Internal ID of a Participant-type Organisation (optional)
        :type x_participant_id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_finance_invoices_serialize(
            limit=limit,
            offset=offset,
            period_from=period_from,
            period_to=period_to,
            statuses=statuses,
            x_participant_id=x_participant_id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "InvoiceGroupBatch",
            '400': "ErrorResponse",
            '401': "ErrorResponse",
            '403': "ErrorResponse",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def get_finance_invoices_without_preload_content(
        self,
        limit: Annotated[int, Field(le=100, strict=True, ge=1, description="Number of records to return on a page")],
        offset: Annotated[int, Field(strict=True, ge=0, description="Offset in the list of records to return")],
        period_from: date,
        period_to: date,
        statuses: List[InvoiceStatus],
        x_participant_id: Annotated[Optional[StrictStr], Field(description="Internal ID of a Participant-type Organisation (optional)")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """get_finance_invoices

        Fetch a paginated, filterable list of Invoices  ---  __Requires Permission:__ (at least one)   * `VIEW_OWN_INVOICES`   * `VIEW_ANY_INVOICES`

        :param limit: Number of records to return on a page (required)
        :type limit: int
        :param offset: Offset in the list of records to return (required)
        :type offset: int
        :param period_from: (required)
        :type period_from: date
        :param period_to: (required)
        :type period_to: date
        :param statuses: (required)
        :type statuses: List[InvoiceStatus]
        :param x_participant_id: Internal ID of a Participant-type Organisation (optional)
        :type x_participant_id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_finance_invoices_serialize(
            limit=limit,
            offset=offset,
            period_from=period_from,
            period_to=period_to,
            statuses=statuses,
            x_participant_id=x_participant_id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "InvoiceGroupBatch",
            '400': "ErrorResponse",
            '401': "ErrorResponse",
            '403': "ErrorResponse",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _get_finance_invoices_serialize(
        self,
        limit,
        offset,
        period_from,
        period_to,
        statuses,
        x_participant_id,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
            'statuses': 'multi',
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        # process the query parameters
        if limit is not None:
            
            _query_params.append(('limit', limit))
            
        if offset is not None:
            
            _query_params.append(('offset', offset))
            
        if period_from is not None:
            if isinstance(period_from, date):
                _query_params.append(
                    (
                        'periodFrom',
                        period_from.isoformat()
                    )
                )
            else:
                _query_params.append(('periodFrom', period_from))
            
        if period_to is not None:
            if isinstance(period_to, date):
                _query_params.append(
                    (
                        'periodTo',
                        period_to.isoformat()
                    )
                )
            else:
                _query_params.append(('periodTo', period_to))
            
        if statuses is not None:
            
            _query_params.append(('statuses', statuses))
            
        # process the header parameters
        if x_participant_id is not None:
            _header_params['X-Participant-Id'] = x_participant_id
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
            'ApiKey'
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/v1/finance/invoices',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def get_finance_settlement_per_day(
        self,
        period_from: date,
        period_to: date,
        sources: List[SettlementSourceType],
        product_types: Annotated[Optional[List[AuctionProductType]], Field(description="List of Auction Product Types (optional)")] = None,
        x_participant_id: Annotated[Optional[StrictStr], Field(description="Internal ID of a Participant-type Organisation (optional)")] = None,
        border_direction: Annotated[Optional[BorderDirection], Field(description="Border Direction (optional)")] = None,
        timescales: Annotated[Optional[List[AuctionTimescale]], Field(description="List of Auction Timescales (optional)")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> List[Settlement]:
        """get_finance_settlement_per_day

        Fetch a filterable list of Settlements per days  ---  __Requires Permission:__ (at least one)   * `VIEW_OWN_SETTLEMENT`   * `VIEW_ANY_SETTLEMENT`

        :param period_from: (required)
        :type period_from: date
        :param period_to: (required)
        :type period_to: date
        :param sources: (required)
        :type sources: List[SettlementSourceType]
        :param product_types: List of Auction Product Types (optional)
        :type product_types: List[AuctionProductType]
        :param x_participant_id: Internal ID of a Participant-type Organisation (optional)
        :type x_participant_id: str
        :param border_direction: Border Direction (optional)
        :type border_direction: BorderDirection
        :param timescales: List of Auction Timescales (optional)
        :type timescales: List[AuctionTimescale]
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_finance_settlement_per_day_serialize(
            period_from=period_from,
            period_to=period_to,
            sources=sources,
            product_types=product_types,
            x_participant_id=x_participant_id,
            border_direction=border_direction,
            timescales=timescales,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "List[Settlement]",
            '400': "ErrorResponse",
            '401': "ErrorResponse",
            '403': "ErrorResponse",
            '422': "ErrorResponse",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def get_finance_settlement_per_day_with_http_info(
        self,
        period_from: date,
        period_to: date,
        sources: List[SettlementSourceType],
        product_types: Annotated[Optional[List[AuctionProductType]], Field(description="List of Auction Product Types (optional)")] = None,
        x_participant_id: Annotated[Optional[StrictStr], Field(description="Internal ID of a Participant-type Organisation (optional)")] = None,
        border_direction: Annotated[Optional[BorderDirection], Field(description="Border Direction (optional)")] = None,
        timescales: Annotated[Optional[List[AuctionTimescale]], Field(description="List of Auction Timescales (optional)")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[List[Settlement]]:
        """get_finance_settlement_per_day

        Fetch a filterable list of Settlements per days  ---  __Requires Permission:__ (at least one)   * `VIEW_OWN_SETTLEMENT`   * `VIEW_ANY_SETTLEMENT`

        :param period_from: (required)
        :type period_from: date
        :param period_to: (required)
        :type period_to: date
        :param sources: (required)
        :type sources: List[SettlementSourceType]
        :param product_types: List of Auction Product Types (optional)
        :type product_types: List[AuctionProductType]
        :param x_participant_id: Internal ID of a Participant-type Organisation (optional)
        :type x_participant_id: str
        :param border_direction: Border Direction (optional)
        :type border_direction: BorderDirection
        :param timescales: List of Auction Timescales (optional)
        :type timescales: List[AuctionTimescale]
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_finance_settlement_per_day_serialize(
            period_from=period_from,
            period_to=period_to,
            sources=sources,
            product_types=product_types,
            x_participant_id=x_participant_id,
            border_direction=border_direction,
            timescales=timescales,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "List[Settlement]",
            '400': "ErrorResponse",
            '401': "ErrorResponse",
            '403': "ErrorResponse",
            '422': "ErrorResponse",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def get_finance_settlement_per_day_without_preload_content(
        self,
        period_from: date,
        period_to: date,
        sources: List[SettlementSourceType],
        product_types: Annotated[Optional[List[AuctionProductType]], Field(description="List of Auction Product Types (optional)")] = None,
        x_participant_id: Annotated[Optional[StrictStr], Field(description="Internal ID of a Participant-type Organisation (optional)")] = None,
        border_direction: Annotated[Optional[BorderDirection], Field(description="Border Direction (optional)")] = None,
        timescales: Annotated[Optional[List[AuctionTimescale]], Field(description="List of Auction Timescales (optional)")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """get_finance_settlement_per_day

        Fetch a filterable list of Settlements per days  ---  __Requires Permission:__ (at least one)   * `VIEW_OWN_SETTLEMENT`   * `VIEW_ANY_SETTLEMENT`

        :param period_from: (required)
        :type period_from: date
        :param period_to: (required)
        :type period_to: date
        :param sources: (required)
        :type sources: List[SettlementSourceType]
        :param product_types: List of Auction Product Types (optional)
        :type product_types: List[AuctionProductType]
        :param x_participant_id: Internal ID of a Participant-type Organisation (optional)
        :type x_participant_id: str
        :param border_direction: Border Direction (optional)
        :type border_direction: BorderDirection
        :param timescales: List of Auction Timescales (optional)
        :type timescales: List[AuctionTimescale]
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_finance_settlement_per_day_serialize(
            period_from=period_from,
            period_to=period_to,
            sources=sources,
            product_types=product_types,
            x_participant_id=x_participant_id,
            border_direction=border_direction,
            timescales=timescales,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "List[Settlement]",
            '400': "ErrorResponse",
            '401': "ErrorResponse",
            '403': "ErrorResponse",
            '422': "ErrorResponse",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _get_finance_settlement_per_day_serialize(
        self,
        period_from,
        period_to,
        sources,
        product_types,
        x_participant_id,
        border_direction,
        timescales,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
            'sources': 'multi',
            'productTypes': 'multi',
            'timescales': 'multi',
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        # process the query parameters
        if period_from is not None:
            if isinstance(period_from, date):
                _query_params.append(
                    (
                        'periodFrom',
                        period_from.isoformat()
                    )
                )
            else:
                _query_params.append(('periodFrom', period_from))
            
        if period_to is not None:
            if isinstance(period_to, date):
                _query_params.append(
                    (
                        'periodTo',
                        period_to.isoformat()
                    )
                )
            else:
                _query_params.append(('periodTo', period_to))
            
        if sources is not None:
            
            _query_params.append(('sources', sources))
            
        if product_types is not None:
            
            _query_params.append(('productTypes', product_types))
            
        if border_direction is not None:
            
            _query_params.append(('borderDirection', border_direction.value))
            
        if timescales is not None:
            
            _query_params.append(('timescales', timescales))
            
        # process the header parameters
        if x_participant_id is not None:
            _header_params['X-Participant-Id'] = x_participant_id
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
            'ApiKey'
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/v1/finance/settlement/day',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def get_finance_settlement_per_source(
        self,
        period_from: date,
        period_to: date,
        sources: List[SettlementSourceType],
        product_types: Annotated[Optional[List[AuctionProductType]], Field(description="List of Auction Product Types (optional)")] = None,
        x_participant_id: Annotated[Optional[StrictStr], Field(description="Internal ID of a Participant-type Organisation (optional)")] = None,
        border_direction: Annotated[Optional[BorderDirection], Field(description="Border Direction (optional)")] = None,
        timescales: Annotated[Optional[List[AuctionTimescale]], Field(description="List of Auction Timescales (optional)")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> List[SettlementPerSource]:
        """get_finance_settlement_per_source

        Fetch a filterable list of Settlements per Source  ---  __Requires Permission:__ (at least one)   * `VIEW_OWN_SETTLEMENT`   * `VIEW_ANY_SETTLEMENT`

        :param period_from: (required)
        :type period_from: date
        :param period_to: (required)
        :type period_to: date
        :param sources: (required)
        :type sources: List[SettlementSourceType]
        :param product_types: List of Auction Product Types (optional)
        :type product_types: List[AuctionProductType]
        :param x_participant_id: Internal ID of a Participant-type Organisation (optional)
        :type x_participant_id: str
        :param border_direction: Border Direction (optional)
        :type border_direction: BorderDirection
        :param timescales: List of Auction Timescales (optional)
        :type timescales: List[AuctionTimescale]
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_finance_settlement_per_source_serialize(
            period_from=period_from,
            period_to=period_to,
            sources=sources,
            product_types=product_types,
            x_participant_id=x_participant_id,
            border_direction=border_direction,
            timescales=timescales,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "List[SettlementPerSource]",
            '400': "ErrorResponse",
            '401': "ErrorResponse",
            '403': "ErrorResponse",
            '422': "ErrorResponse",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def get_finance_settlement_per_source_with_http_info(
        self,
        period_from: date,
        period_to: date,
        sources: List[SettlementSourceType],
        product_types: Annotated[Optional[List[AuctionProductType]], Field(description="List of Auction Product Types (optional)")] = None,
        x_participant_id: Annotated[Optional[StrictStr], Field(description="Internal ID of a Participant-type Organisation (optional)")] = None,
        border_direction: Annotated[Optional[BorderDirection], Field(description="Border Direction (optional)")] = None,
        timescales: Annotated[Optional[List[AuctionTimescale]], Field(description="List of Auction Timescales (optional)")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[List[SettlementPerSource]]:
        """get_finance_settlement_per_source

        Fetch a filterable list of Settlements per Source  ---  __Requires Permission:__ (at least one)   * `VIEW_OWN_SETTLEMENT`   * `VIEW_ANY_SETTLEMENT`

        :param period_from: (required)
        :type period_from: date
        :param period_to: (required)
        :type period_to: date
        :param sources: (required)
        :type sources: List[SettlementSourceType]
        :param product_types: List of Auction Product Types (optional)
        :type product_types: List[AuctionProductType]
        :param x_participant_id: Internal ID of a Participant-type Organisation (optional)
        :type x_participant_id: str
        :param border_direction: Border Direction (optional)
        :type border_direction: BorderDirection
        :param timescales: List of Auction Timescales (optional)
        :type timescales: List[AuctionTimescale]
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_finance_settlement_per_source_serialize(
            period_from=period_from,
            period_to=period_to,
            sources=sources,
            product_types=product_types,
            x_participant_id=x_participant_id,
            border_direction=border_direction,
            timescales=timescales,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "List[SettlementPerSource]",
            '400': "ErrorResponse",
            '401': "ErrorResponse",
            '403': "ErrorResponse",
            '422': "ErrorResponse",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def get_finance_settlement_per_source_without_preload_content(
        self,
        period_from: date,
        period_to: date,
        sources: List[SettlementSourceType],
        product_types: Annotated[Optional[List[AuctionProductType]], Field(description="List of Auction Product Types (optional)")] = None,
        x_participant_id: Annotated[Optional[StrictStr], Field(description="Internal ID of a Participant-type Organisation (optional)")] = None,
        border_direction: Annotated[Optional[BorderDirection], Field(description="Border Direction (optional)")] = None,
        timescales: Annotated[Optional[List[AuctionTimescale]], Field(description="List of Auction Timescales (optional)")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """get_finance_settlement_per_source

        Fetch a filterable list of Settlements per Source  ---  __Requires Permission:__ (at least one)   * `VIEW_OWN_SETTLEMENT`   * `VIEW_ANY_SETTLEMENT`

        :param period_from: (required)
        :type period_from: date
        :param period_to: (required)
        :type period_to: date
        :param sources: (required)
        :type sources: List[SettlementSourceType]
        :param product_types: List of Auction Product Types (optional)
        :type product_types: List[AuctionProductType]
        :param x_participant_id: Internal ID of a Participant-type Organisation (optional)
        :type x_participant_id: str
        :param border_direction: Border Direction (optional)
        :type border_direction: BorderDirection
        :param timescales: List of Auction Timescales (optional)
        :type timescales: List[AuctionTimescale]
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_finance_settlement_per_source_serialize(
            period_from=period_from,
            period_to=period_to,
            sources=sources,
            product_types=product_types,
            x_participant_id=x_participant_id,
            border_direction=border_direction,
            timescales=timescales,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "List[SettlementPerSource]",
            '400': "ErrorResponse",
            '401': "ErrorResponse",
            '403': "ErrorResponse",
            '422': "ErrorResponse",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _get_finance_settlement_per_source_serialize(
        self,
        period_from,
        period_to,
        sources,
        product_types,
        x_participant_id,
        border_direction,
        timescales,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
            'sources': 'multi',
            'productTypes': 'multi',
            'timescales': 'multi',
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        # process the query parameters
        if period_from is not None:
            if isinstance(period_from, date):
                _query_params.append(
                    (
                        'periodFrom',
                        period_from.isoformat()
                    )
                )
            else:
                _query_params.append(('periodFrom', period_from))
            
        if period_to is not None:
            if isinstance(period_to, date):
                _query_params.append(
                    (
                        'periodTo',
                        period_to.isoformat()
                    )
                )
            else:
                _query_params.append(('periodTo', period_to))
            
        if sources is not None:
            
            _query_params.append(('sources', sources))
            
        if product_types is not None:
            
            _query_params.append(('productTypes', product_types))
            
        if border_direction is not None:
            
            _query_params.append(('borderDirection', border_direction.value))
            
        if timescales is not None:
            
            _query_params.append(('timescales', timescales))
            
        # process the header parameters
        if x_participant_id is not None:
            _header_params['X-Participant-Id'] = x_participant_id
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
            'ApiKey'
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/v1/finance/settlement/source',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def get_finance_uiosi_overview(
        self,
        delivery_day: date,
        border_direction: Annotated[BorderDirection, Field(description="Border Direction")],
        timescale: Annotated[AuctionTimescale, Field(description="Auction Timescale")],
        x_participant_id: Annotated[Optional[StrictStr], Field(description="Internal ID of a Participant-type Organisation (optional)")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> UiosiOverview:
        """get_finance_uiosi_overview

        Fetch \"Use it or Sell it\" data by given filters  ---  __Requires Permission:__ (at least one)   * `VIEW_OWN_UIOSI`   * `VIEW_ANY_UIOSI`

        :param delivery_day: (required)
        :type delivery_day: date
        :param border_direction: Border Direction (required)
        :type border_direction: BorderDirection
        :param timescale: Auction Timescale (required)
        :type timescale: AuctionTimescale
        :param x_participant_id: Internal ID of a Participant-type Organisation (optional)
        :type x_participant_id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_finance_uiosi_overview_serialize(
            delivery_day=delivery_day,
            border_direction=border_direction,
            timescale=timescale,
            x_participant_id=x_participant_id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "UiosiOverview",
            '400': "ErrorResponse",
            '401': "ErrorResponse",
            '403': "ErrorResponse",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def get_finance_uiosi_overview_with_http_info(
        self,
        delivery_day: date,
        border_direction: Annotated[BorderDirection, Field(description="Border Direction")],
        timescale: Annotated[AuctionTimescale, Field(description="Auction Timescale")],
        x_participant_id: Annotated[Optional[StrictStr], Field(description="Internal ID of a Participant-type Organisation (optional)")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[UiosiOverview]:
        """get_finance_uiosi_overview

        Fetch \"Use it or Sell it\" data by given filters  ---  __Requires Permission:__ (at least one)   * `VIEW_OWN_UIOSI`   * `VIEW_ANY_UIOSI`

        :param delivery_day: (required)
        :type delivery_day: date
        :param border_direction: Border Direction (required)
        :type border_direction: BorderDirection
        :param timescale: Auction Timescale (required)
        :type timescale: AuctionTimescale
        :param x_participant_id: Internal ID of a Participant-type Organisation (optional)
        :type x_participant_id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_finance_uiosi_overview_serialize(
            delivery_day=delivery_day,
            border_direction=border_direction,
            timescale=timescale,
            x_participant_id=x_participant_id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "UiosiOverview",
            '400': "ErrorResponse",
            '401': "ErrorResponse",
            '403': "ErrorResponse",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def get_finance_uiosi_overview_without_preload_content(
        self,
        delivery_day: date,
        border_direction: Annotated[BorderDirection, Field(description="Border Direction")],
        timescale: Annotated[AuctionTimescale, Field(description="Auction Timescale")],
        x_participant_id: Annotated[Optional[StrictStr], Field(description="Internal ID of a Participant-type Organisation (optional)")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """get_finance_uiosi_overview

        Fetch \"Use it or Sell it\" data by given filters  ---  __Requires Permission:__ (at least one)   * `VIEW_OWN_UIOSI`   * `VIEW_ANY_UIOSI`

        :param delivery_day: (required)
        :type delivery_day: date
        :param border_direction: Border Direction (required)
        :type border_direction: BorderDirection
        :param timescale: Auction Timescale (required)
        :type timescale: AuctionTimescale
        :param x_participant_id: Internal ID of a Participant-type Organisation (optional)
        :type x_participant_id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_finance_uiosi_overview_serialize(
            delivery_day=delivery_day,
            border_direction=border_direction,
            timescale=timescale,
            x_participant_id=x_participant_id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "UiosiOverview",
            '400': "ErrorResponse",
            '401': "ErrorResponse",
            '403': "ErrorResponse",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _get_finance_uiosi_overview_serialize(
        self,
        delivery_day,
        border_direction,
        timescale,
        x_participant_id,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        # process the query parameters
        if delivery_day is not None:
            if isinstance(delivery_day, date):
                _query_params.append(
                    (
                        'deliveryDay',
                        delivery_day.isoformat()
                    )
                )
            else:
                _query_params.append(('deliveryDay', delivery_day))
            
        if border_direction is not None:
            
            _query_params.append(('borderDirection', border_direction.value))
            
        if timescale is not None:
            
            _query_params.append(('timescale', timescale.value))
            
        # process the header parameters
        if x_participant_id is not None:
            _header_params['X-Participant-Id'] = x_participant_id
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
            'ApiKey'
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/v1/finance/uiosi-overview',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )





# coding: utf-8

"""
    Platform API

    _OpenAPI specification for the **Platform API** of **Empire**, the allocation and nomination platform of BritNed_  ---  Additional documentation available in the API's [GitHub repository](https://github.com/britned/empire-platform-api) 

    The version of the OpenAPI document: 6.0.4
    Contact: britned.info@britned.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import json
from enum import Enum
from typing_extensions import Self


class InvoiceActionType(str, Enum):
    """
    InvoiceActionType
    """

    """
    allowed enum values
    """
    GENERATED = 'GENERATED'
    EDITED = 'EDITED'
    SENT = 'SENT'
    RESENT = 'RESENT'
    MARKED_AS_PAID = 'MARKED_AS_PAID'

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of InvoiceActionType from a JSON string"""
        return cls(json.loads(json_str))





# coding: utf-8

"""
    Platform API

    _OpenAPI specification for the **Platform API** of **Empire**, the allocation and nomination platform of BritNed_  ---  Additional documentation available in the API's [GitHub repository](https://github.com/britned/empire-platform-api) 

    The version of the OpenAPI document: 6.0.4
    Contact: britned.info@britned.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import json
from enum import Enum
from typing_extensions import Self


class SettlementSubSourceType(str, Enum):
    """
    SettlementSubSourceType
    """

    """
    allowed enum values
    """
    EXPLICIT_AUCTION_MULTI_ANNUAL = 'EXPLICIT_AUCTION_MULTI_ANNUAL'
    EXPLICIT_AUCTION_ANNUAL = 'EXPLICIT_AUCTION_ANNUAL'
    EXPLICIT_AUCTION_SEASONAL = 'EXPLICIT_AUCTION_SEASONAL'
    EXPLICIT_AUCTION_QUARTERLY = 'EXPLICIT_AUCTION_QUARTERLY'
    EXPLICIT_AUCTION_MONTHLY = 'EXPLICIT_AUCTION_MONTHLY'
    EXPLICIT_AUCTION_MULTI_DAY = 'EXPLICIT_AUCTION_MULTI_DAY'
    EXPLICIT_AUCTION_WEEKLY = 'EXPLICIT_AUCTION_WEEKLY'
    EXPLICIT_AUCTION_WEEKEND = 'EXPLICIT_AUCTION_WEEKEND'
    EXPLICIT_AUCTION_LONG_WEEKEND = 'EXPLICIT_AUCTION_LONG_WEEKEND'
    EXPLICIT_AUCTION_DA = 'EXPLICIT_AUCTION_DA'
    EXPLICIT_AUCTION_ID = 'EXPLICIT_AUCTION_ID'
    LT_RETURN_MULTI_ANNUAL = 'LT_RETURN_MULTI_ANNUAL'
    LT_RETURN_ANNUAL = 'LT_RETURN_ANNUAL'
    LT_RETURN_SEASONAL = 'LT_RETURN_SEASONAL'
    LT_RETURN_QUARTERLY = 'LT_RETURN_QUARTERLY'
    LT_RETURN_MONTHLY = 'LT_RETURN_MONTHLY'
    LT_RETURN_MULTI_DAY = 'LT_RETURN_MULTI_DAY'
    LT_RETURN_WEEKLY = 'LT_RETURN_WEEKLY'
    LT_RETURN_WEEKEND = 'LT_RETURN_WEEKEND'
    LT_RETURN_LONG_WEEKEND = 'LT_RETURN_LONG_WEEKEND'
    CURTAILMENT_LT = 'CURTAILMENT_LT'
    CURTAILMENT_DA = 'CURTAILMENT_DA'
    CURTAILMENT_ID = 'CURTAILMENT_ID'
    BUY_NOW_DA = 'BUY_NOW_DA'
    BUY_NOW_ID = 'BUY_NOW_ID'
    UIOSI_DA = 'UIOSI_DA'
    UIOSI_LT = 'UIOSI_LT'

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of SettlementSubSourceType from a JSON string"""
        return cls(json.loads(json_str))





# coding: utf-8

"""
    Platform API

    _OpenAPI specification for the **Platform API** of **Empire**, the allocation and nomination platform of BritNed_  ---  Additional documentation available in the API's [GitHub repository](https://github.com/britned/empire-platform-api) 

    The version of the OpenAPI document: 6.0.4
    Contact: britned.info@britned.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import json
from enum import Enum
from typing_extensions import Self


class Permission(str, Enum):
    """
    Permission
    """

    """
    allowed enum values
    """
    VIEW_PUBLISHED_AUCTIONS = 'VIEW_PUBLISHED_AUCTIONS'
    VIEW_ANY_AUCTIONS = 'VIEW_ANY_AUCTIONS'
    MANAGE_AUCTIONS = 'MANAGE_AUCTIONS'
    VIEW_AUCTION_BIDS = 'VIEW_AUCTION_BIDS'
    MANAGE_LT_AUCTION_BIDS = 'MANAGE_LT_AUCTION_BIDS'
    MANAGE_DA_ID_AUCTION_BIDS = 'MANAGE_DA_ID_AUCTION_BIDS'
    VIEW_AUCTION_DEFAULTS = 'VIEW_AUCTION_DEFAULTS'
    MANAGE_AUCTION_DEFAULTS = 'MANAGE_AUCTION_DEFAULTS'
    VIEW_CAPACITY_OVERVIEW = 'VIEW_CAPACITY_OVERVIEW'
    VIEW_NTC_OVERVIEW = 'VIEW_NTC_OVERVIEW'
    SUBMIT_NTC_OVERRIDE = 'SUBMIT_NTC_OVERRIDE'
    VIEW_NTC_REDUCTIONS = 'VIEW_NTC_REDUCTIONS'
    MANAGE_NTC_REDUCTIONS = 'MANAGE_NTC_REDUCTIONS'
    VIEW_NTC_ADDITIONS = 'VIEW_NTC_ADDITIONS'
    MANAGE_NTC_ADDITIONS = 'MANAGE_NTC_ADDITIONS'
    VIEW_UNPLANNED_OUTAGES = 'VIEW_UNPLANNED_OUTAGES'
    MANAGE_UNPLANNED_OUTAGES = 'MANAGE_UNPLANNED_OUTAGES'
    VIEW_PLANNED_OUTAGES = 'VIEW_PLANNED_OUTAGES'
    MANAGE_PLANNED_OUTAGES = 'MANAGE_PLANNED_OUTAGES'
    VIEW_OWN_TRANSMISSION_RIGHTS = 'VIEW_OWN_TRANSMISSION_RIGHTS'
    VIEW_ANY_TRANSMISSION_RIGHTS = 'VIEW_ANY_TRANSMISSION_RIGHTS'
    VIEW_OWN_TIMESCALE_NOMINATIONS = 'VIEW_OWN_TIMESCALE_NOMINATIONS'
    MANAGE_OWN_TIMESCALE_NOMINATIONS = 'MANAGE_OWN_TIMESCALE_NOMINATIONS'
    VIEW_ANY_TIMESCALE_NOMINATIONS = 'VIEW_ANY_TIMESCALE_NOMINATIONS'
    MANAGE_ANY_TIMESCALE_NOMINATIONS = 'MANAGE_ANY_TIMESCALE_NOMINATIONS'
    VIEW_SOSO_NOMINATIONS = 'VIEW_SOSO_NOMINATIONS'
    MANAGE_SOSO_NOMINATIONS = 'MANAGE_SOSO_NOMINATIONS'
    VIEW_BPP_NOMINATIONS = 'VIEW_BPP_NOMINATIONS'
    MANAGE_BPP_NOMINATIONS = 'MANAGE_BPP_NOMINATIONS'
    VIEW_OWN_TIMESCALE_OR_BPP_AGGREGATED_NOMINATIONS = 'VIEW_OWN_TIMESCALE_OR_BPP_AGGREGATED_NOMINATIONS'
    VIEW_ANY_TIMESCALE_OR_BPP_AGGREGATED_NOMINATIONS = 'VIEW_ANY_TIMESCALE_OR_BPP_AGGREGATED_NOMINATIONS'
    VIEW_SOSO_AGGREGATED_NOMINATIONS = 'VIEW_SOSO_AGGREGATED_NOMINATIONS'
    VIEW_OWN_DEFAULT_BIDS = 'VIEW_OWN_DEFAULT_BIDS'
    MANAGE_OWN_DEFAULT_BIDS = 'MANAGE_OWN_DEFAULT_BIDS'
    VIEW_ANY_DEFAULT_BIDS = 'VIEW_ANY_DEFAULT_BIDS'
    MANAGE_ANY_DEFAULT_BIDS = 'MANAGE_ANY_DEFAULT_BIDS'
    VIEW_OWN_DEFAULT_NOMINATIONS = 'VIEW_OWN_DEFAULT_NOMINATIONS'
    MANAGE_OWN_DEFAULT_NOMINATIONS = 'MANAGE_OWN_DEFAULT_NOMINATIONS'
    VIEW_ANY_DEFAULT_NOMINATIONS = 'VIEW_ANY_DEFAULT_NOMINATIONS'
    MANAGE_ANY_DEFAULT_NOMINATIONS = 'MANAGE_ANY_DEFAULT_NOMINATIONS'
    VIEW_NOM_WINDOW_OVERRIDES = 'VIEW_NOM_WINDOW_OVERRIDES'
    MANAGE_NOM_WINDOW_OVERRIDES = 'MANAGE_NOM_WINDOW_OVERRIDES'
    VIEW_CRISIS = 'VIEW_CRISIS'
    MANAGE_CRISIS_ACTIONS = 'MANAGE_CRISIS_ACTIONS'
    MANAGE_CRISIS_MESSAGES = 'MANAGE_CRISIS_MESSAGES'
    VIEW_ANY_ORGANISATIONS = 'VIEW_ANY_ORGANISATIONS'
    MANAGE_ANY_ORGANISATIONS = 'MANAGE_ANY_ORGANISATIONS'
    VIEW_OWN_ORGANISATIONS = 'VIEW_OWN_ORGANISATIONS'
    VIEW_OWN_USERS = 'VIEW_OWN_USERS'
    VIEW_ANY_USERS = 'VIEW_ANY_USERS'
    MANAGE_OWN_USERS = 'MANAGE_OWN_USERS'
    MANAGE_ANY_USERS = 'MANAGE_ANY_USERS'
    INVITE_USERS = 'INVITE_USERS'
    IMPERSONATE_USERS = 'IMPERSONATE_USERS'
    VIEW_ICO_DASHBOARD = 'VIEW_ICO_DASHBOARD'
    VIEW_PARTICIPANT_DASHBOARD = 'VIEW_PARTICIPANT_DASHBOARD'
    VIEW_GENERAL_SYSTEM_MESSAGES = 'VIEW_GENERAL_SYSTEM_MESSAGES'
    VIEW_OPERATIONAL_SYSTEM_MESSAGES = 'VIEW_OPERATIONAL_SYSTEM_MESSAGES'
    VIEW_PARTICIPANT_MESSAGES = 'VIEW_PARTICIPANT_MESSAGES'
    VIEW_OWN_WEBHOOKS = 'VIEW_OWN_WEBHOOKS'
    VIEW_ANY_WEBHOOKS = 'VIEW_ANY_WEBHOOKS'
    MANAGE_OWN_WEBHOOKS = 'MANAGE_OWN_WEBHOOKS'
    MANAGE_ANY_WEBHOOKS = 'MANAGE_ANY_WEBHOOKS'
    VIEW_BUSINESS_SETTINGS = 'VIEW_BUSINESS_SETTINGS'
    MANAGE_BUSINESS_SETTINGS = 'MANAGE_BUSINESS_SETTINGS'
    VIEW_PROTECTED_CONFIG_VARIABLES = 'VIEW_PROTECTED_CONFIG_VARIABLES'
    VIEW_OWN_BIDDING_CONFIGURATION = 'VIEW_OWN_BIDDING_CONFIGURATION'
    MANAGE_OWN_BIDDING_CONFIGURATION = 'MANAGE_OWN_BIDDING_CONFIGURATION'
    VIEW_ANY_BIDDING_CONFIGURATION = 'VIEW_ANY_BIDDING_CONFIGURATION'
    MANAGE_ANY_BIDDING_CONFIGURATION = 'MANAGE_ANY_BIDDING_CONFIGURATION'
    VIEW_OWN_ORGANISATION_DOCUMENTS = 'VIEW_OWN_ORGANISATION_DOCUMENTS'
    MANAGE_OWN_ORGANISATION_DOCUMENTS = 'MANAGE_OWN_ORGANISATION_DOCUMENTS'
    VIEW_ANY_ORGANISATION_DOCUMENTS = 'VIEW_ANY_ORGANISATION_DOCUMENTS'
    MANAGE_ANY_ORGANISATION_DOCUMENTS = 'MANAGE_ANY_ORGANISATION_DOCUMENTS'
    VIEW_BPP = 'VIEW_BPP'
    MANAGE_BPP = 'MANAGE_BPP'
    VIEW_ANY_BUY_NOW_OFFERS = 'VIEW_ANY_BUY_NOW_OFFERS'
    VIEW_OWN_BUY_NOW_OFFERS = 'VIEW_OWN_BUY_NOW_OFFERS'
    MANAGE_BUY_NOW_OFFERS = 'MANAGE_BUY_NOW_OFFERS'
    PURCHASE_BUY_NOW_OFFERS = 'PURCHASE_BUY_NOW_OFFERS'
    VIEW_ANY_SECONDARY_MARKET_RETURNS = 'VIEW_ANY_SECONDARY_MARKET_RETURNS'
    VIEW_OWN_SECONDARY_MARKET_RETURNS = 'VIEW_OWN_SECONDARY_MARKET_RETURNS'
    MANAGE_SECONDARY_MARKET_RETURNS = 'MANAGE_SECONDARY_MARKET_RETURNS'
    VIEW_ANY_SECONDARY_MARKET_TRANSFERS = 'VIEW_ANY_SECONDARY_MARKET_TRANSFERS'
    VIEW_OWN_SECONDARY_MARKET_TRANSFERS = 'VIEW_OWN_SECONDARY_MARKET_TRANSFERS'
    MANAGE_SECONDARY_MARKET_LT_TRANSFERS = 'MANAGE_SECONDARY_MARKET_LT_TRANSFERS'
    MANAGE_SECONDARY_MARKET_DA_ID_TRANSFERS = 'MANAGE_SECONDARY_MARKET_DA_ID_TRANSFERS'
    VIEW_BUSINESS_PROCESSES = 'VIEW_BUSINESS_PROCESSES'
    MANAGE_BUSINESS_PROCESSES = 'MANAGE_BUSINESS_PROCESSES'
    VIEW_DATA_FLOWS = 'VIEW_DATA_FLOWS'
    MANAGE_DATA_FLOWS = 'MANAGE_DATA_FLOWS'
    MANAGE_OWN_MANUAL_FILE_UPLOAD_BIDS = 'MANAGE_OWN_MANUAL_FILE_UPLOAD_BIDS'
    MANAGE_OWN_MANUAL_FILE_UPLOAD_NOMINATIONS = 'MANAGE_OWN_MANUAL_FILE_UPLOAD_NOMINATIONS'
    MANAGE_ANY_MANUAL_FILE_UPLOAD = 'MANAGE_ANY_MANUAL_FILE_UPLOAD'
    VIEW_OWN_AUDIT_LOGS = 'VIEW_OWN_AUDIT_LOGS'
    VIEW_ANY_AUDIT_LOGS = 'VIEW_ANY_AUDIT_LOGS'
    VIEW_ANY_FINANCE_REPORTS = 'VIEW_ANY_FINANCE_REPORTS'
    VIEW_OWN_FINANCE_REPORTS = 'VIEW_OWN_FINANCE_REPORTS'
    VIEW_OWN_SETTLEMENT = 'VIEW_OWN_SETTLEMENT'
    VIEW_ANY_SETTLEMENT = 'VIEW_ANY_SETTLEMENT'
    VIEW_OWN_INVOICES = 'VIEW_OWN_INVOICES'
    VIEW_ANY_INVOICES = 'VIEW_ANY_INVOICES'
    MANAGE_INVOICES = 'MANAGE_INVOICES'
    VIEW_OWN_UIOSI = 'VIEW_OWN_UIOSI'
    VIEW_ANY_UIOSI = 'VIEW_ANY_UIOSI'
    VIEW_CREDIT_OVERVIEW = 'VIEW_CREDIT_OVERVIEW'
    VIEW_HELP_FAQ = 'VIEW_HELP_FAQ'

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of Permission from a JSON string"""
        return cls(json.loads(json_str))





# coding: utf-8

"""
    Platform API

    _OpenAPI specification for the **Platform API** of **Empire**, the allocation and nomination platform of BritNed_  ---  Additional documentation available in the API's [GitHub repository](https://github.com/britned/empire-platform-api) 

    The version of the OpenAPI document: 6.0.4
    Contact: britned.info@britned.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictInt
from typing import Any, ClassVar, Dict, List, Optional, Union
from typing_extensions import Annotated
from empire_platform_api_public_client.models.auction_result_congestion_rent import AuctionResultCongestionRent
from empire_platform_api_public_client.models.long_term_auction_results_allocated_capacity import LongTermAuctionResultsAllocatedCapacity
from empire_platform_api_public_client.models.long_term_auction_results_bids import LongTermAuctionResultsBids
from typing import Optional, Set
from typing_extensions import Self

class LongTermAuctionResults(BaseModel):
    """
    LongTermAuctionResults
    """ # noqa: E501
    congestion_rent: Optional[AuctionResultCongestionRent] = Field(default=None, alias="congestionRent")
    bids: List[LongTermAuctionResultsBids]
    total_requested_capacity: StrictInt = Field(description="Capacity value in kilowatts (kW) - the required system precision allows for handling capacity values as integers", alias="totalRequestedCapacity")
    total_allocated_capacity: StrictInt = Field(description="Capacity value in kilowatts (kW) - the required system precision allows for handling capacity values as integers", alias="totalAllocatedCapacity")
    allocated_capacity: List[LongTermAuctionResultsAllocatedCapacity] = Field(alias="allocatedCapacity")
    marginal_price: Union[Annotated[float, Field(multiple_of=0.01, strict=True)], Annotated[int, Field(strict=True)]] = Field(description="Currency value in Euros (€), accepted with a precision of maximum 2 decimal places", alias="marginalPrice")
    reserve_price: Optional[Union[Annotated[float, Field(multiple_of=0.01, strict=True)], Annotated[int, Field(strict=True)]]] = Field(default=None, description="Currency value in Euros (€), accepted with a precision of maximum 2 decimal places", alias="reservePrice")
    __properties: ClassVar[List[str]] = ["congestionRent", "bids", "totalRequestedCapacity", "totalAllocatedCapacity", "allocatedCapacity", "marginalPrice", "reservePrice"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of LongTermAuctionResults from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of congestion_rent
        if self.congestion_rent:
            _dict['congestionRent'] = self.congestion_rent.to_dict()
        # override the default output from pydantic by calling `to_dict()` of each item in bids (list)
        _items = []
        if self.bids:
            for _item_bids in self.bids:
                if _item_bids:
                    _items.append(_item_bids.to_dict())
            _dict['bids'] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in allocated_capacity (list)
        _items = []
        if self.allocated_capacity:
            for _item_allocated_capacity in self.allocated_capacity:
                if _item_allocated_capacity:
                    _items.append(_item_allocated_capacity.to_dict())
            _dict['allocatedCapacity'] = _items
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of LongTermAuctionResults from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "congestionRent": AuctionResultCongestionRent.from_dict(obj["congestionRent"]) if obj.get("congestionRent") is not None else None,
            "bids": [LongTermAuctionResultsBids.from_dict(_item) for _item in obj["bids"]] if obj.get("bids") is not None else None,
            "totalRequestedCapacity": obj.get("totalRequestedCapacity"),
            "totalAllocatedCapacity": obj.get("totalAllocatedCapacity"),
            "allocatedCapacity": [LongTermAuctionResultsAllocatedCapacity.from_dict(_item) for _item in obj["allocatedCapacity"]] if obj.get("allocatedCapacity") is not None else None,
            "marginalPrice": obj.get("marginalPrice"),
            "reservePrice": obj.get("reservePrice")
        })
        return _obj


